@@ -3,11 +3,11 @@ import re
 import sys
 from io import StringIO
 from pathlib import Path
-from typing import Iterator, List, Optional, Pattern, Set, Union
+from typing import Dict, Iterable, Iterator, List, Optional, Pattern, Set, Union
 
 import click
 import toml
-from black import get_gitignore
+from black import find_project_root, get_gitignore
 from pathspec import PathSpec
 
 from snakefmt import DEFAULT_LINE_LENGTH, __version__
@@ -37,41 +37,47 @@ def construct_regex(regex: str) -> Pattern[str]:
     )
 
 
-def read_snakefmt_defaults_from_pyproject_toml(
-    ctx: click.Context, param: click.Parameter, value: Optional[str] = None
-) -> Optional[str]:
-    """Inject Snakefmt configuration from "pyproject.toml" into defaults in `ctx`.
-    Returns the path to a successfully found and read configuration file, None
-    otherwise.
-    """
-    if not value:
-        path = Path("pyproject.toml")
-        if path.is_file():
-            value = str(path)
-        else:
-            return None
-
+def read_snakefmt_config(path: Optional[str]) -> Dict[str, str]:
+    """Parse Snakefmt configuration from provided toml."""
+    if path is None:
+        return dict()
     try:
-        pyproject_toml = toml.load(value)
-        config = pyproject_toml.get("tool", {}).get("snakefmt", {})
+        config_toml = toml.load(path)
+        config = config_toml.get("tool", {}).get("snakefmt", {})
+        config = {k.replace("--", "").replace("-", "_"): v for k, v in config.items()}
+        return config
     except (toml.TomlDecodeError, OSError) as error:
         raise click.FileError(
-            filename=value, hint=f"Error reading configuration file: {error}"
+            filename=path, hint=f"Error reading configuration file: {error}"
         )
 
-    if not config:
-        return None
+
+def find_pyproject_toml(start_path: Iterable[str]) -> Optional[str]:
+    root = find_project_root(start_path)
+    config_file = root / "pyproject.toml"
+    return str(config_file) if config_file.is_file() else None
+
+
+def inject_snakefmt_config(
+    ctx: click.Context, param: click.Parameter, config_file: Optional[str] = None
+) -> Optional[str]:
+    """
+    If no config file argument provided, parses "pyproject.toml" if one exists.
+    Injects any parsed configuration into the relevant parameters to the click `ctx`.
+    """
+    if config_file is None:
+        config_file = find_pyproject_toml(ctx.params.get("src", ()))
+
+    config = read_snakefmt_config(config_file)
 
     if ctx.default_map is None:
         ctx.default_map = {}
-    ctx.default_map.update(  # type: ignore  # bad types in .pyi
-        {k.replace("--", "").replace("-", "_"): v for k, v in config.items()}
-    )
-    return value
+    ctx.default_map.update(config)  # type: ignore  # bad types in .pyi
+    return config_file
 
 
 def get_snakefiles_in_dir(
-    path: Path, include: Pattern[str], exclude: Pattern[str], gitignore: PathSpec,
+    path: Path, include: Pattern[str], exclude: Pattern[str], gitignore: PathSpec
 ) -> Iterator[Path]:
     """Generate all files under `path` whose paths are not excluded by the
     `exclude` regex, but are included by the `include` regex.
@@ -111,10 +117,9 @@ def get_snakefiles_in_dir(
 @click.option(
     "-l",
     "--line-length",
-    default=DEFAULT_LINE_LENGTH,
-    show_default=True,
+    default=None,
     type=int,
-    help="Lines longer than INT will be wrapped.",
+    help=f"Lines longer than INT will be wrapped. [default: {DEFAULT_LINE_LENGTH}]",
     metavar="INT",
 )
 @click.option(
@@ -174,6 +179,7 @@ def get_snakefiles_in_dir(
     type=click.Path(
         exists=True, file_okay=True, dir_okay=True, readable=True, allow_dash=True
     ),
+    is_eager=True,
 )
 @click.option(
     "-c",
@@ -183,7 +189,7 @@ def get_snakefiles_in_dir(
     ),
     metavar="PATH",
     is_eager=True,
-    callback=read_snakefmt_defaults_from_pyproject_toml,
+    callback=inject_snakefmt_config,
     help=(
         "Read configuration from PATH. By default, will try to read from "
         "`./pyproject.toml`"
@@ -277,7 +283,7 @@ def main(
         try:
             snakefile = Snakefile(StringIO(original_content))
             formatter = Formatter(
-                snakefile, line_length=line_length, black_config=config
+                snakefile, line_length=line_length, black_config_file=config
             )
             formatted_content = formatter.get_formatted()
         except Exception as error:
